@@ -17,6 +17,8 @@ BEGIN {
       my $home = ($ENV{NETDISCO_HOME} || (getpwuid($uid))[7] || $ENV{HOME});
       $ENV{NETDISCO_HOME} ||= $home;
 
+      $ENV{NETDISCO_DO} ||= File::Spec->catfile($FindBin::RealBin, 'netdisco-do');
+
       my $auto = dir(dist_dir('App-Netdisco'))->absolute;
 
       $ENV{DANCER_APPDIR}  ||= $auto->stringify;
@@ -31,8 +33,6 @@ BEGIN {
 
       $ENV{DANCER_PUBLIC} ||= $auto->subdir('public')->stringify;
       $ENV{DANCER_VIEWS}  ||= $auto->subdir('views')->stringify;
-
-      $ENV{POETRY_CACHE_DIR} ||= dir($home, 'python', 'cache', 'pypoetry')->stringify;
   }
 
   {
