@@ -8,6 +8,8 @@ use Dancer::Plugin::Auth::Extensible;
 use URI ();
 use URL::Encode 'url_params_mixed';
 use App::Netdisco::Util::Device 'match_to_setting';
+use App::Netdisco::Util::Port 'sync_portctl_roles';
+use App::Netdisco::Util::Web 'request_is_device';
 
 # build view settings for port connected nodes and devices
 set('connected_properties' => [
@@ -22,6 +24,12 @@ set('port_display_properties' => [
   grep { $_ =~ m/^p_/ } keys %{ setting('sidebar_defaults')->{'device_ports'} }
 ]);
 
+# load and cache device port control configuration
+hook 'before' => sub {
+  return unless request_is_device;
+  sync_portctl_roles();
+};
+
 hook 'before_template' => sub {
   my $tokens = shift;
 
