@@ -19,6 +19,7 @@ use NetAddr::IP::Lite ':lower';
 use Storable 'dclone';
 use List::MoreUtils ();
 use JSON::PP ();
+use Path::Class qw/file dir/;
 use Encode;
 
 register_worker({ phase => 'early', driver => 'snmp',
@@ -93,8 +94,9 @@ register_worker({ phase => 'early', driver => 'snmp',
   $try_vendor =~ s/^(?:\.?1.3.6.1.4.1|enterprises)// if $try_vendor;
 
   # fix up unknown vendor (enterprise number -> organization)
-  if ((not $device->vendor or $device->vendor eq 'unknown')
-        and $try_vendor and $try_vendor =~ m/^\.(\d+)/) {
+  if ((not $device->vendor or $device->vendor eq 'unknown'
+        or $device->vendor =~ m/^${enterprises_mib}/)
+      and $try_vendor and $try_vendor =~ m/^\.(\d+)/) {
 
       my $number = $1;
       debug sprintf ' searching for Enterprise Number "%s"', $number;
@@ -107,16 +109,30 @@ register_worker({ phase => 'early', driver => 'snmp',
 
   # fix up model using products OID cache
   if ((not $device->model or $device->model eq 'unknown'
-        or $device->model =~ m/(?:product|enterprise|1\.3\.6\.1)/i) and $try_vendor) {
+        or $device->model =~ m/(?:product|enterprise|1\.3\.6\.1)/i)
+      and $try_vendor) {
 
       my $oid = '.1.3.6.1.4.1' . $try_vendor;
       debug sprintf ' searching for Product ID "%s"', ('enterprises' . $try_vendor);
       my $object = schema('netdisco')->resultset('Product')->find($oid);
       if ($object) {
-          debug sprintf ' ... found Product "%s" (replaced "%s")',
+          debug sprintf ' ...found Product "%s" (replaced "%s")',
             $object->leaf, ($device->model || '');
           $device->set_column( model => $object->leaf );
       }
+      else {
+          debug '  also searching netdisco-mibs...';
+          my $file = file((setting('mibhome') || dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'netdisco-mibs')),
+            'EXTRAS', 'reports', 'all_leafs_only');
+          my $target = quotemeta($oid);
+          my $leaf = `grep -E '^$target,' '$file' | cut -d, -f2`; # BACKTICKS
+          if ($leaf) {
+              chomp($leaf);
+              debug sprintf '  ...found Product "%s" (replaced "%s")',
+                $leaf, ($device->model || '');
+              $device->set_column( model => $leaf );
+          }
+      }
   }
 
   # remove superfluous vendor names from model names
